@@ -27,7 +27,8 @@ def test_png_colorful():
     qr = segno.make('Penny Lane', error='h')
     out = io.BytesIO()
     qr.save(out, 'png', dark=dark, data_dark=data_dark, data_light=data_light)
-    data_uri = qr.png_data_uri(dark=dark, data_dark=data_dark, data_light=data_light)
+    data_uri = qr.png_data_uri(dark=dark, data_dark=data_dark,
+                               data_light=data_light)
     assert data_uri
     d = base64.b64decode(data_uri[len('data:image/png;base64,'):])
     assert out.getvalue() == d
@@ -40,8 +41,10 @@ def test_svg_colorful():
     data_light = 'yellow'
     qr = segno.make('Penny Lane', error='h')
     out = io.BytesIO()
-    qr.save(out, 'svg', xmldecl=False, nl=False, dark=dark, data_dark=data_dark, data_light=data_light)
-    data_uri = qr.svg_data_uri(dark=dark, data_dark=data_dark, data_light=data_light)
+    qr.save(out, 'svg', xmldecl=False, nl=False, dark=dark, data_dark=data_dark,
+            data_light=data_light)
+    data_uri = qr.svg_data_uri(dark=dark, data_dark=data_dark,
+                               data_light=data_light)
     assert data_uri
     d = data_uri[len('data:image/svg+xml;charset=utf-8,'):]
     assert quote(replace_quotes(out.getvalue()), safe=b'') == d
